@@ -43,12 +43,6 @@
 
 extern "C"
 {
-#if defined(MPICH_NAME)
-#if !defined( MPICH_FEELPP_HAS_MPI_WIN )
-#define MPICH_FEELPP_HAS_MPI_WIN
-  struct MPI_Win {};
-#endif
-#endif
 #include <petscmat.h>
 }
 
