@@ -30,7 +30,7 @@
 
 
 
-#if defined( HAVE_PETSC_H )
+#if defined( FEELPP_HAS_PETSC_H )
 #include <feel/feelcore/feelpetsc.hpp>
 #include <feel/feelalg/glas.hpp>
 #include <feel/feelalg/vectorpetsc.hpp>
@@ -374,25 +374,25 @@ void SolverNonLinearPetsc<T>::init ()
 
     int ierr=0;
 
-    // if the non linear solver type is define by the user int the code
-    if (this->getType() != SELECT_IN_ARGLIST )
-        {
-            switch (this->getType())
-                {
-                case LINE_SEARCH :
-                    {
-                        ierr = SNESSetType(M_snes, SNESLS);
-                        CHKERRABORT(PETSC_COMM_WORLD,ierr);
-                    }
-                    break;
-                case TRUST_REGION :
-                    {
-                        ierr = SNESSetType(M_snes, SNESTR);
-                        CHKERRABORT(PETSC_COMM_WORLD,ierr);
-                    }
-                    break;
-                }
-        }
+    // if the non linear solver type is define by the user in the code
+    switch (this->getType())
+    {
+    case LINE_SEARCH :
+    {
+        ierr = SNESSetType(M_snes, SNESLS);
+        CHKERRABORT(PETSC_COMM_WORLD,ierr);
+    }
+    break;
+    case TRUST_REGION :
+    {
+        ierr = SNESSetType(M_snes, SNESTR);
+        CHKERRABORT(PETSC_COMM_WORLD,ierr);
+    }
+    break;
+    case SELECT_IN_ARGLIST:
+        // no-op
+        break;
+    }
 
 
     double __relResTol,__absResTol,__absSolTol;
@@ -839,4 +839,4 @@ template class SolverNonLinearPetsc<double>;
 
 } // Feel
 
-#endif // #ifdef HAVE_PETSC
+#endif // #ifdef FEELPP_HAS_PETSC
