@@ -31,7 +31,7 @@
 #include <feel/feelalg/vectorpetsc.hpp>
 #include <feel/feelalg/matrixpetsc.hpp>
 
-#if defined( HAVE_PETSC_H )
+#if defined( FEELPP_HAS_PETSC_H )
 
 
 
@@ -1047,4 +1047,4 @@ template class VectorPetscMPI<double>;
 
 } // Feel
 
-#endif // HAVE_PETSC_H
+#endif // FEELPP_HAS_PETSC_H
