@@ -41,12 +41,6 @@
 
 extern "C"
 {
-#if defined(MPICH_NAME)
-#if !defined( MPICH_FEELPP_HAS_MPI_WIN )
-#define MPICH_FEELPP_HAS_MPI_WIN
-  struct MPI_Win {};
-#endif
-#endif
 #include <petscmat.h>
 }
 
@@ -268,7 +262,7 @@ public:
      */
     //@{
 
-    const bool destroy_vec_on_exit() const {return _M_destroy_vec_on_exit;}
+    bool destroy_vec_on_exit() const {return _M_destroy_vec_on_exit;}
 
     /**
      * @return dimension of the vector. This
