@@ -153,7 +153,7 @@ init_unit_test_suite( int /*argc*/, char** /*argv[]*/ )
 {
   test_suite* test = BOOST_TEST_SUITE( "2D spectral accuracy tests" );
 
-#if defined( FEELPP_HAVE_QD_REAL)
+#if defined( FEELPP_HAS_QD_REAL)
     unsigned int old_cw;
     fpu_fix_start(&old_cw);
 #endif
